==> miktex-21.1.tar.xz: miktex-21.1/Programs/MiKTeX/Setup/MFC/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Setup.rc
//
#define IDR_MANIFEST                    1
#define IDS_HEADER_SETTINGS             100
#define IDS_SUBHEADER_SETTINGS          101
#define IDS_HEADER_POST_INSTALL         102
#define IDS_INSTALL_DIR_NOT_EMPTY       103
#define IDS_CANCEL_DOWNLOAD             104
#define IDS_CANCEL_SETUP                105
#define IDS_SUBHEADER_POST_INSTALL      106
#define IDS_FINISH_ERROR                111
#define IDS_REMEDY                      112
#define IDS_VIEW_LOG_FILE               114
#define IDS_HEADER_SHARED               118
#define IDS_SUBHEADER_SHARED            119
#define IDS_SETUPWIZ                    120
#define IDS_HEADER_INSTALLDIR           121
#define IDS_SUBHEADER_INSTALLDIR        122
#define IDR_MAINFRAME                   128
#define IDR_LICENSE                     129
#define IDS_HEADER_INFOLIST             129
#define IDS_SUBHEADER_INFOLIST          130
#define IDS_HEADER_FILECOPY             131
#define IDS_SUBHEADER_FILECOPY          132
#define IDS_HEADER_TASK                 133
#define IDS_SUBHEADER_TASK              134
#define IDS_HEADER_LOCAL_REPOSITORY     135
#define IDS_SUBHEADER_LOCAL_REPOSITORY  136
#define IDS_HEADER_PACKAGE_SET          137
#define IDS_SUBHEADER_PACKAGE_SET       138
#define IDS_HEADER_REMOTE_REPOSITORY    139
#define IDS_SUBHEADER_REMOTE_REPOSITORY 140
#define IDP_NOT_LOCAL_REPOSITORY        142
#define IDS_DOWNLOAD_COMPLETE           143
#define IDS_BROWSE_LOCAL                148
#define IDS_HEADER_LICENSE              149
#define IDS_SUBHEADER_LICENSE           150
#define IDD_WELCOME                     151
#define IDD_INSTALLDIR                  152
#define IDD_INFOLIST                    154
#define IDD_FINISH                      155
#define IDD_FILECOPY                    157
#define IDD_SHARED                      158
#define IDD_TASK                        160
#define IDB_HEADER                      161
#define IDB_WATERMARK                   162
#define IDA_FILECOPY                    163
#define IDA_DOWNLOAD                    164
#define IDD_LOCAL_REPOSITORY            167
#define IDD_PACKAGE_SET_INSTALL         168
#define IDD_REMOTE_REPOSITORY           169
#define IDD_MD_TASK                     170
#define IDD_LICENSE                     171
#define IDD_PACKAGE_SET_DOWNLOAD        172
#define IDD_SETTINGS                    173
#define IDD_PROXY_AUTHENTICATION        174
#define IDD_CONNECTION_SETTINGS         175
#define IDD_POST_INSTALL                176
#define IDC_LIST                        1000
#define IDC_WELCOME                     1001
#define IDC_USE_PROXY                   1003
#define IDC_PROGRESS1                   1005
#define IDC_CONNECTION_SETTINGS         1006
#define IDC_PATHNAME                    1007
#define IDC_PROGRESS2                   1008
#define IDC_PROXY_HOST                  1009
#define IDC_PROXY_PORT                  1010
#define IDC_AUTH_REQUIRED               1011
#define IDC_STATIC_ADDRESS              1013
#define IDC_STATIC_PORT                 1014
#define IDC_INFO                        1015
#define IDC_PROXY_NAME                  1016
#define IDC_PROXY_PASSWORD              1017
#define IDC_PACKAGE                     1018
#define IDC_PROGRESS1_TITLE             1019
#define IDC_PROGRESS2_TITLE             1020
#define IDC_SHARED                      1022
#define IDC_JUST_FOR_ME                 1023
#define IDC_REPORT                      1029
#define IDC_DOWNLOAD_ONLY               1030
#define IDC_ANI                         1031
#define IDC_MESSAGE                     1032
#define IDC_INSTALL_FROM_LOCAL_REPOSITORY 1033
#define IDC_SMALL                       1034
#define IDC_INSTALL_FROM_REMOTE_REPOSITORY 1035
#define IDC_TOTAL                       1036
#define IDC_ETA                         1037
#define IDC_ETA_TITLE                   1038
#define IDC_CHECK                       1038
#define IDC_STATUS                      1039
#define IDC_PREPARE_MIKTEXDIRECT        1040
#define IDC_INSTALL                     1041
#define IDC_LICENSE                     1042
#define IDC_ACCEPT_LICENSE              1043
#define IDC_TEXMF_ROOT                  1044
#define IDC_COMBO1                      1045
#define IDC_INSTALL_ON_THE_FLY          1047
#define IDC_FILENAME                    1048
#define IDC_BROWSE                      1049
#define IDC_PETITION                    1051
#define IDC_CHECK_UPDATES               1055

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        132
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1056
#define _APS_NEXT_SYMED_VALUE           177
#endif
#endif

==> miktex-23.4.tar.xz: miktex-23.4/Programs/MiKTeX/Setup/MFC/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Setup.rc
//
#define IDR_MANIFEST                    1
#define IDS_HEADER_SETTINGS             100
#define IDS_SUBHEADER_SETTINGS          101
#define IDS_HEADER_POST_INSTALL         102
#define IDS_INSTALL_DIR_NOT_EMPTY       103
#define IDS_CANCEL_DOWNLOAD             104
#define IDS_CANCEL_SETUP                105
#define IDS_SUBHEADER_POST_INSTALL      106
#define IDS_FINISH_ERROR                111
#define IDS_REMEDY                      112
#define IDS_VIEW_LOG_FILE               114
#define IDS_HEADER_SHARED               118
#define IDS_SUBHEADER_SHARED            119
#define IDS_SETUPWIZ                    120
#define IDS_HEADER_INSTALLDIR           121
#define IDS_SUBHEADER_INSTALLDIR        122
#define IDR_MAINFRAME                   128
#define IDR_LICENSE                     129
#define IDS_HEADER_INFOLIST             129
#define IDS_SUBHEADER_INFOLIST          130
#define IDS_HEADER_FILECOPY             131
#define IDS_SUBHEADER_FILECOPY          132
#define IDS_HEADER_TASK                 133
#define IDS_SUBHEADER_TASK              134
#define IDS_HEADER_LOCAL_REPOSITORY     135
#define IDS_SUBHEADER_LOCAL_REPOSITORY  136
#define IDS_HEADER_PACKAGE_SET          137
#define IDS_SUBHEADER_PACKAGE_SET       138
#define IDS_HEADER_REMOTE_REPOSITORY    139
#define IDS_SUBHEADER_REMOTE_REPOSITORY 140
#define IDP_NOT_LOCAL_REPOSITORY        142
#define IDS_DOWNLOAD_COMPLETE           143
#define IDS_BROWSE_LOCAL                148
#define IDS_HEADER_LICENSE              149
#define IDS_SUBHEADER_LICENSE           150
#define IDD_WELCOME                     151
#define IDD_INSTALLDIR                  152
#define IDD_INFOLIST                    154
#define IDD_FINISH                      155
#define IDD_FILECOPY                    157
#define IDD_SHARED                      158
#define IDD_TASK                        160
#define IDB_HEADER                      161
#define IDB_WATERMARK                   162
#define IDA_FILECOPY                    163
#define IDA_DOWNLOAD                    164
#define IDD_LOCAL_REPOSITORY            167
#define IDD_PACKAGE_SET_INSTALL         168
#define IDD_REMOTE_REPOSITORY           169
#define IDD_MD_TASK                     170
#define IDD_LICENSE                     171
#define IDD_PACKAGE_SET_DOWNLOAD        172
#define IDD_SETTINGS                    173
#define IDD_PROXY_AUTHENTICATION        174
#define IDD_CONNECTION_SETTINGS         175
#define IDD_POST_INSTALL                176
#define IDC_LIST                        1000
#define IDC_WELCOME                     1001
#define IDC_USE_PROXY                   1003
#define IDC_PROGRESS1                   1005
#define IDC_CONNECTION_SETTINGS         1006
#define IDC_PATHNAME                    1007
#define IDC_PROGRESS2                   1008
#define IDC_PROXY_HOST                  1009
#define IDC_PROXY_PORT                  1010
#define IDC_AUTH_REQUIRED               1011
#define IDC_STATIC_ADDRESS              1013
#define IDC_STATIC_PORT                 1014
#define IDC_INFO                        1015
#define IDC_PROXY_NAME                  1016
#define IDC_PROXY_PASSWORD              1017
#define IDC_PACKAGE                     1018
#define IDC_PROGRESS1_TITLE             1019
#define IDC_PROGRESS2_TITLE             1020
#define IDC_SHARED                      1022
#define IDC_JUST_FOR_ME                 1023
#define IDC_REPORT                      1029
#define IDC_DOWNLOAD_ONLY               1030
#define IDC_ANI                         1031
#define IDC_MESSAGE                     1032
#define IDC_INSTALL_FROM_LOCAL_REPOSITORY 1033
#define IDC_ADVANCED                       1034
#define IDC_INSTALL_FROM_REMOTE_REPOSITORY 1035
#define IDC_COMPLETE                       1036
#define IDC_ETA                         1037
#define IDC_ETA_TITLE                   1038
#define IDC_CHECK                       1038
#define IDC_STATUS                      1039
#define IDC_PREPARE_MIKTEXDIRECT        1040
#define IDC_INSTALL                     1041
#define IDC_LICENSE                     1042
#define IDC_ACCEPT_LICENSE              1043
#define IDC_TEXMF_ROOT                  1044
#define IDC_COMBO1                      1045
#define IDC_INSTALL_ON_THE_FLY          1047
#define IDC_FILENAME                    1048
#define IDC_BROWSE                      1049
#define IDC_PETITION                    1051
#define IDC_CHECK_UPDATES               1055

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        132
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1056
#define _APS_NEXT_SYMED_VALUE           177
#endif
#endif
